---
title: <span class="badge builder"></span> ExprTypeThresholdConditionsUnloadEvaluator
---
# <span class="badge builder"></span> ExprTypeThresholdConditionsUnloadEvaluator

## Constructor

```python
ExprTypeThresholdConditionsUnloadEvaluator()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> expr.ExprTypeThresholdConditionsUnloadEvaluator
```

### <span class="badge object-method"></span> params

```python
def params(params: list[float]) -> typing.Self
```

### <span class="badge object-method"></span> type_val

e.g. "gt"

```python
def type_val(type_val: typing.Literal["gt", "lt", "eq", "ne", "gte", "lte", "within_range", "outside_range", "within_range_included", "outside_range_included"]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ExprTypeThresholdConditionsUnloadEvaluator](./object-ExprTypeThresholdConditionsUnloadEvaluator.md)
